==> client-sdk-react-1.16.0.tgz: package/src/components/Participants/ParticipantsGridView/ParticipantsGridView.tsx <==
import React from 'react'
import { useZocksStore } from '../../../app'
import { selectLocalParticipant } from '../../../store'
import { Participant } from '../../Participant'
import { usePagedParticipants, useSortRemoteParticipantsForGridView } from '../hooks'
import { MultipleParticipantViewProps } from '../model'
import zocksStyle from './ParticipantsGridView.module.scss'
import { getClassName, getMergedClassNames } from '../../common'

export const ParticipantsGridView: React.FC<MultipleParticipantViewProps> = ({
  pageSize = 25,
  participantElement,
  styles,
}) => {
  const localParticipant = useZocksStore(selectLocalParticipant)

  const remoteParticipants = useSortRemoteParticipantsForGridView(pageSize)
  const allParticipants = [localParticipant, ...remoteParticipants]

  const { displayedParticipants, hasNextPage, hasPreviousPage, nextPage, previousPage } = usePagedParticipants(
    allParticipants,
    pageSize
  )
  const mergedStyles = getMergedClassNames(zocksStyle, styles)

  const gridClass = getGridClassForParticipants(Math.min(pageSize, allParticipants.length), mergedStyles)

  const ParticipantElement = participantElement ?? Participant

  return (
    <div className={getClassName('participants-grid-view', mergedStyles)}>
      {hasPreviousPage && <PreviousButton onClick={previousPage} mergedStyles={mergedStyles} />}
      <div className={`${getClassName('participants-grid-view__grid', mergedStyles)} ${gridClass}`}>
        {displayedParticipants.map((participant) => (
          <ParticipantElement key={participant.id} participant={participant} withAudio={true} styles={mergedStyles} />
        ))}
      </div>
      {hasNextPage && <NextButton onClick={nextPage} mergedStyles={mergedStyles} />}
    </div>
  )
}

const getGridClassForParticipants = (numberOfParticipants: number, mergedStyles: { [key: string]: string }): string => {
  switch (true) {
    case numberOfParticipants <= 1:
      return getClassName('participants-grid-view__grid--1x1', mergedStyles)
    case numberOfParticipants === 2:
      return getClassName('participants-grid-view__grid--2x1', mergedStyles)
    case numberOfParticipants <= 4:
      return getClassName('participants-grid-view__grid--2x2', mergedStyles)
    case numberOfParticipants <= 6:
      return getClassName('participants-grid-view__grid--3x2', mergedStyles)
    case numberOfParticipants <= 9:
      return getClassName('participants-grid-view__grid--3x3', mergedStyles)
    case numberOfParticipants <= 16:
      return getClassName('participants-grid-view__grid--4x4', mergedStyles)
    default:
      return getClassName('participants-grid-view__grid--5x5', mergedStyles)
  }
}

const PreviousButton: React.FC<{ onClick: () => void; mergedStyles?: { [key: string]: string } }> = ({
  onClick,
  mergedStyles,
}) => (
  <button
    className={`${getClassName('participants-grid-view__button', mergedStyles)} ${getClassName(
      'participants-grid-view__previous-button',
      mergedStyles
    )}`}
    onClick={onClick}
    aria-label='Previous'
  >
    <div className={getClassName('participants-grid-view__previous-button-icon', mergedStyles)} />
  </button>
)

const NextButton: React.FC<{ onClick: () => void; mergedStyles?: { [key: string]: string } }> = ({
  onClick,
  mergedStyles,
}) => (
  <button
    className={`${getClassName('participants-grid-view__button', mergedStyles)} ${getClassName(
      'participants-grid-view__next-button',
      mergedStyles
    )}`}
    onClick={onClick}
    aria-label='Next'
  >
    <div className={getClassName('participants-grid-view__next-button-icon', mergedStyles)} />
  </button>
)

==> client-sdk-react-2.1.2.tgz: package/src/components/Participants/ParticipantsGridView/ParticipantsGridView.tsx <==
import React from 'react'
import { useZocksStore } from '../../../app'
import { selectLocalParticipant } from '../../../store'
import { Participant } from '../../Participant'
import { usePagedParticipants, useSortRemoteParticipantsForGridView } from '../hooks'
import { MultipleParticipantViewProps } from '../model'
import zocksStyle from './ParticipantsGridView.module.scss'
import { getClassName, getMergedClassNames } from '../../common'

export const ParticipantsGridView: React.FC<MultipleParticipantViewProps> = ({ pageSize = 25, components, styles }) => {
  const localParticipant = useZocksStore(selectLocalParticipant)

  const remoteParticipants = useSortRemoteParticipantsForGridView(pageSize)
  const allParticipants = [localParticipant, ...remoteParticipants]

  const { displayedParticipants, hasNextPage, hasPreviousPage, nextPage, previousPage } = usePagedParticipants(
    allParticipants,
    pageSize
  )
  const mergedStyles = getMergedClassNames(zocksStyle, styles)

  const gridClass = getGridClassForParticipants(Math.min(pageSize, allParticipants.length), mergedStyles)

  const ParticipantElement = components?.Participant ?? Participant

  return (
    <div className={getClassName('participants-grid-view', mergedStyles)}>
      {hasPreviousPage && <PreviousButton onClick={previousPage} mergedStyles={mergedStyles} />}
      <div className={`${getClassName('participants-grid-view__grid', mergedStyles)} ${gridClass}`}>
        {displayedParticipants.map((participant) => (
          <ParticipantElement key={participant.id} participant={participant} withAudio={true} styles={mergedStyles} />
        ))}
      </div>
      {hasNextPage && <NextButton onClick={nextPage} mergedStyles={mergedStyles} />}
    </div>
  )
}

const getGridClassForParticipants = (numberOfParticipants: number, mergedStyles: { [key: string]: string }): string => {
  switch (true) {
    case numberOfParticipants <= 1:
      return getClassName('participants-grid-view__grid--1x1', mergedStyles)
    case numberOfParticipants === 2:
      return getClassName('participants-grid-view__grid--2x1', mergedStyles)
    case numberOfParticipants <= 4:
      return getClassName('participants-grid-view__grid--2x2', mergedStyles)
    case numberOfParticipants <= 6:
      return getClassName('participants-grid-view__grid--3x2', mergedStyles)
    case numberOfParticipants <= 9:
      return getClassName('participants-grid-view__grid--3x3', mergedStyles)
    case numberOfParticipants <= 16:
      return getClassName('participants-grid-view__grid--4x4', mergedStyles)
    default:
      return getClassName('participants-grid-view__grid--5x5', mergedStyles)
  }
}

const PreviousButton: React.FC<{ onClick: () => void; mergedStyles?: { [key: string]: string } }> = ({
  onClick,
  mergedStyles,
}) => (
  <button
    className={`${getClassName('participants-grid-view__button', mergedStyles)} ${getClassName(
      'participants-grid-view__previous-button',
      mergedStyles
    )}`}
    onClick={onClick}
    aria-label='Previous'
  >
    <div className={getClassName('participants-grid-view__previous-button-icon', mergedStyles)} />
  </button>
)

const NextButton: React.FC<{ onClick: () => void; mergedStyles?: { [key: string]: string } }> = ({
  onClick,
  mergedStyles,
}) => (
  <button
    className={`${getClassName('participants-grid-view__button', mergedStyles)} ${getClassName(
      'participants-grid-view__next-button',
      mergedStyles
    )}`}
    onClick={onClick}
    aria-label='Next'
  >
    <div className={getClassName('participants-grid-view__next-button-icon', mergedStyles)} />
  </button>
)
